@@ -1,4 +1,4 @@
-from typing import List, Optional
+from typing import Optional
 
 from fastapi import FastAPI
 from fastapi.testclient import TestClient
@@ -11,7 +11,7 @@ from .utils import PYDANTIC_V2, needs_pydanticv2
 class SubItem(BaseModel):
     subname: str
     sub_description: Optional[str] = None
-    tags: List[str] = []
+    tags: list[str] = []
     if PYDANTIC_V2:
         model_config = {"json_schema_serialization_defaults_required": True}
 
@@ -44,11 +44,11 @@ def get_app_client(separate_input_output_schemas: bool = True) -> TestClient:
         return item
 
     @app.post("/items-list/")
-    def create_item_list(item: List[Item]):
+    def create_item_list(item: list[Item]):
         return item
 
     @app.get("/items/")
-    def read_items() -> List[Item]:
+    def read_items() -> list[Item]:
         return [
             Item(
                 name="Portal Gun",
