@@ -1,5 +1,5 @@
 import sys
-from typing import Any, List, Union
+from typing import Any, Union
 
 from tests.utils import pydantic_snapshot, skip_module_if_py_gte_314
 
@@ -21,18 +21,18 @@ class Item(BaseModel):
     size: int
     description: Union[str, None] = None
     sub: SubItem
-    multi: List[SubItem] = []
+    multi: list[SubItem] = []
 
 
 app = FastAPI()
 
 
 @app.post("/item")
-def handle_item(data: Item) -> List[Item]:
+def handle_item(data: Item) -> list[Item]:
     return [data, data]
 
 
-@app.post("/item-filter", response_model=List[Item])
+@app.post("/item-filter", response_model=list[Item])
 def handle_item_filter(data: Item) -> Any:
     extended_data = data.dict()
     extended_data.update({"secret_data": "classified", "internal_id": 12345})
@@ -41,14 +41,14 @@ def handle_item_filter(data: Item) -> Any:
 
 
 @app.post("/item-list")
-def handle_item_list(data: List[Item]) -> Item:
+def handle_item_list(data: list[Item]) -> Item:
     if data:
         return data[0]
     return Item(title="", size=0, sub=SubItem(name=""))
 
 
 @app.post("/item-list-filter", response_model=Item)
-def handle_item_list_filter(data: List[Item]) -> Any:
+def handle_item_list_filter(data: list[Item]) -> Any:
     if data:
         extended_data = data[0].dict()
         extended_data.update({"secret_data": "classified", "internal_id": 12345})
@@ -58,12 +58,12 @@ def handle_item_list_filter(data: List[Item]) -> Any:
 
 
 @app.post("/item-list-to-list")
-def handle_item_list_to_list(data: List[Item]) -> List[Item]:
+def handle_item_list_to_list(data: list[Item]) -> list[Item]:
     return data
 
 
-@app.post("/item-list-to-list-filter", response_model=List[Item])
-def handle_item_list_to_list_filter(data: List[Item]) -> Any:
+@app.post("/item-list-to-list-filter", response_model=list[Item])
+def handle_item_list_to_list_filter(data: list[Item]) -> Any:
     if data:
         extended_data = data[0].dict()
         extended_data.update({"secret_data": "classified", "internal_id": 12345})
