@@ -3,14 +3,13 @@ import importlib
 import pytest
 from fastapi.testclient import TestClient
 
-from ...utils import needs_py39, needs_pydanticv2
+from ...utils import needs_pydanticv2
 
 
 @pytest.fixture(
     name="client",
     params=[
-        pytest.param("tutorial007"),
-        pytest.param("tutorial007_py39", marks=needs_py39),
+        pytest.param("tutorial007_py39"),
     ],
 )
 def get_client(request: pytest.FixtureRequest):
