@@ -23,7 +23,7 @@ from ...utils import needs_py310
 @pytest.fixture(
     name="mod",
     params=[
-        "tutorial001_an",
+        "tutorial001_an_py39",
         pytest.param("tutorial001_an_py310", marks=needs_py310),
     ],
 )
