@@ -3,15 +3,14 @@ import importlib
 import pytest
 from fastapi.testclient import TestClient
 
-from ...utils import needs_py39, needs_py310, needs_pydanticv2
+from ...utils import needs_py310, needs_pydanticv2
 
 
 @pytest.fixture(
     name="client",
     params=[
-        "tutorial001",
+        pytest.param("tutorial001_py39"),
         pytest.param("tutorial001_py310", marks=needs_py310),
-        pytest.param("tutorial001_py39", marks=needs_py39),
     ],
 )
 def get_client(request: pytest.FixtureRequest) -> TestClient:
